pub struct DropMoveWrapper<T: DropMove>(/* private fields */);Expand description
Implementations
Sourceimpl<T: DropMove> DropMoveWrapper<T>
impl<T: DropMove> DropMoveWrapper<T>
Sourcepub fn into_inner(self_: Self) -> T
pub fn into_inner(self_: Self) -> T
Convert into the inner structure T.
This is an associated function so that will not conflict with any methods of the inner type,
which are accessible through Deref.