DropMove

Trait DropMove 

pub trait DropMove: DropMoveTypes {
    // Provided method
    fn drop_move(self_: DropHandle<Self>) { ... }
}
A variant of Drop that allows moving out of the value being dropped.

This trait must be implemented by the inner structure generated by drop_move_wrap!.

Provided Methods

fn drop_move(self_: DropHandle<Self>)

Drop the value, by move instead of by reference.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors